//******************************************************************************
//                       NEC COMMANDS for AN-SOF 9.10                           
// Find command descriptions at this link:
// https://antennasimulator.com/index.php/knowledge-base/importing-wires/ 
//******************************************************************************

// CM – Comments
function Output = CM(Comment)
         Output = 'CM ' + Comment;
endfunction

// GW – Linear Wire
function Output = GW(Tag, Segments, X1, Y1, Z1, X2, Y2, Z2, Radius)
         Output = 'GW ' + string(Tag) + ' ' + string(Segments) + ' ' ...
         + string(X1) + ' ' + string(Y1) + ' ' + string(Z1) + ' ' ...
         + string(X2) + ' ' + string(Y2) + ' ' + string(Z2) + ' ' ...
         + string(Radius);
endfunction

// GH – Helix
function Output = GH(Tag, Segments, Spacing, Length, R, R, R, R, Radius)
         Output = 'GH ' + string(Tag) + ' ' + string(Segments) + ' ' ...
         + string(Spacing) + ' ' + string(Length) + ' ' + string(R) + ' ' ...
         + string(R) + ' ' + string(R) + ' ' + string(R) + ' ' ...
         + string(Radius);
endfunction

// GA – Arc
function Output = GA(Tag, Segments, R, Ang1, Ang2, Radius)
         Output = 'GA ' + string(Tag) + ' ' + string(Segments) + ' ' ...
         + string(Ang1) + ' ' + string(Ang2) + ' ' + string(Radius);
endfunction

// GB – AN-SOF Arc
function Output = GB(Tag, Segments, Type, X1,Y1,Z1, X2,Y2,Z2, X3,Y3,Z3, Radius)
         Output = 'GB ' + string(Tag) + ' ' + string(Segments) + ' ' ...
         + string(Type) + ' ' ...
         + string(X1) + ' ' + string(Y1) + ' ' + string(Z1) + ' ' ...
         + string(X2) + ' ' + string(Y2) + ' ' + string(Z2) + ' ' ...
         + string(X3) + ' ' + string(Y3) + ' ' + string(Z3) + ' ' ...
         + string(Radius);
endfunction

// GM – Coordinate Transformation
function Output = GM(N, rotX, rotY, rotZ, DX, DY, DZ)
         Output = 'GM 0 ' + string(N) + ' ' ...
         + string(rotX) + ' ' + string(rotY) + ' ' + string(rotZ) + ' ' ...
         + string(DX) + ' ' + string(DY) + ' ' + string(DZ) + ' 0';
endfunction

// GS – Scale Structure Dimensions
function Output = GS(Scale)
         Output = 'GS 0 0 ' + string(Scale);
endfunction

// GE – Ground connections
function Output = GE(Type)
         Output = 'GE ' + string(Type);
endfunction

// GN – Real ground
function Output = GN(Type, Screen, Epsilon, Sigma, Length, WireRadius)
         Output = 'GN ' + string(Type) + ' ' + string(Screen) + ' 0 0 ' ...
         + string(Epsilon) + ' ' + string(Sigma) + ' ' ...
         + string(Length) + ' ' + string(WireRadius);
endfunction

// TL – Transmission Line
function Output = TL(Wire1, Seg1, Wire2, Seg2, Z0, Length, Y1r, Y1i, Y2r, Y2i)
         Output = 'TL ' + string(Wire1) + ' ' + string(Seg1) + ' ' ...
         + string(Wire2) + ' ' + string(Seg2) + ' ' ...
         + string(Z0) + ' ' + string(Length) + ' ' ...
         + string(Y1r) + ' ' + string(Y1i) + ' ' ...
         + string(Y2r) + ' ' + string(Y2i);
endfunction

// LD – Load impedance - L in nH / C in uF
function Output = LD(Type, Wire, Seg, R, L, C)
         Output = 'LD ' + string(Type) + ' ' + string(Wire) + ' ' ...
         + string(Seg) + ' ' + string(Seg) + ' ' ...
         + string(R) + ' ' + string(L) + 'E-9 ' + string(C) + 'E-6';
endfunction

// IS – Insulated wire
function Output = IS(Wire, Epsilon, Radius)
         Output = 'IS 0 ' + string(Wire) + ' 0 0 ' ...
         + string(Epsilon) + ' 0 ' + string(Radius);
endfunction

// FR – Frequencies
function Output = FR(Type, Num, Freq, Df)
         Output = 'FR ' + string(Type) + ' ' + string(Num) + ' 0 0 ' ...
         + string(Freq) + ' ' + string(Df);
endfunction

// EX – Excitation
function Output = EX(Type, Wire, Seg, Real, Imag)
         Output = 'EX ' + string(Type) + ' ' + string(Wire) + ' ' ...
         + string(Seg) + ' 0 ' + string(Real) + ' ' + string(Imag);
endfunction

// EK - Exact Kernel
function Output = EK()
         Output = 'EK';
endfunction

// RP – Radiation pattern
function Output = RP(Ntheta, Nphi, Theta, Phi, Dtheta, Dphi, R)
         Output = 'RP 0 ' + string(Ntheta) + ' ' + string(Nphi) + ' 1001 ' ...
         + string(Theta) + ' ' + string(Phi) + ' ' ...
         + string(Dtheta) + ' ' + string(Dphi) + ' ' + string(R);
endfunction
